@@ -50,7 +50,7 @@ Active_window_condition::Active_window_condition( Windowdef_list* window_P,
 
 Active_window_condition::~Active_window_condition()
     {
-    disconnect( windows_handler, NULL, this, NULL );
+    disconnect( windows_handler, nullptr, this, nullptr );
     delete _window;
     }
 
